@@ -3,6 +3,10 @@ print.isoph=function(x, ...){
   print(x$call)
   cat("\nEstimated monotone function, hazard ratio and level set:\n")
   print(x$est)
+  if(!is.na(x$exp.beta)){
+    a1.0=paste("\n exp(beta): ",x$exp.beta,"\n",sep='')
+    cat(a1.0)
+  }
 
   a1.1=paste("\nNumber of events/subjects was ",x$nevent,"/",x$n,".",sep='')
   a1.2=paste("\nNumber of distinct covariates associated with observed events was ",x$njump,".",sep='')
@@ -12,9 +16,9 @@ print.isoph=function(x, ...){
   cat(a1.3)
   
   if(x$conv=="converged"){
-    a2=paste("\n\nAlgorithm was ",x$conv,".",sep='')
+    a2=paste("\n\nAlgorithm was ",x$conv,".\n",sep='')
   }else if(x$conv=="not converged"){
-    a2=paste("\n\nAlgorithm was ",x$conv,". Results were questinable",sep='')
+    a2=paste("\n\nAlgorithm was ",x$conv,". Results were questinable.\n",sep='')
   }
   cat(a2)
 }
